@@ -1,5 +1,5 @@
 /*
- * "$Id: ipp-var.c 12701 2015-06-08 18:33:44Z msweet $"
+ * "$Id: ipp-var.c 12769 2015-06-30 16:13:48Z msweet $"
  *
  * CGI <-> IPP variable routines for CUPS.
  *
@@ -222,6 +222,9 @@ cgiGetIPPObjects(ipp_t *response,	/* I - IPP response */
 	      break;
 
           case IPP_TAG_INTEGER :
+	      if (!strncmp(ippGetName(attr), "time-at-", 8))
+	        break;			/* Ignore time-at-xxx */
+
 	      for (i = 0; !add && i < attr->num_values; i ++)
 	      {
 	        char	buf[255];	/* Number buffer */
@@ -1547,5 +1550,5 @@ cgiText(const char *message)		/* I - Message */
 
 
 /*
- * End of "$Id: ipp-var.c 12701 2015-06-08 18:33:44Z msweet $".
+ * End of "$Id: ipp-var.c 12769 2015-06-30 16:13:48Z msweet $".
  */
