@@ -1,9 +1,9 @@
 /*
- * "$Id: ppd-cache.c 12124 2014-08-28 15:37:22Z msweet $"
+ * "$Id: ppd-cache.c 12434 2015-01-28 16:29:06Z msweet $"
  *
  * PPD cache implementation for CUPS.
  *
- * Copyright 2010-2014 by Apple Inc.
+ * Copyright 2010-2015 by Apple Inc.
  *
  * These coded instructions, statements, and computer programs are the
  * property of Apple Inc. and are protected by Federal copyright
@@ -2691,6 +2691,25 @@ pwg_unppdize_name(const char *ppd,	/* I - PPD keyword */
 	*end;				/* End of name buffer */
 
 
+  if (_cups_islower(*ppd))
+  {
+   /*
+    * Already lowercase name, use as-is?
+    */
+
+    const char *ppdptr;			/* Pointer into PPD keyword */
+
+    for (ppdptr = ppd + 1; *ppdptr; ppdptr ++)
+      if (_cups_isupper(*ppdptr) || strchr(dashchars, *ppdptr))
+        break;
+
+    if (!*ppdptr)
+    {
+      strlcpy(name, ppd, namesize);
+      return;
+    }
+  }
+
   for (ptr = name, end = name + namesize - 1; *ppd && ptr < end; ppd ++)
   {
     if (_cups_isalnum(*ppd) || *ppd == '-')
@@ -2712,5 +2731,5 @@ pwg_unppdize_name(const char *ppd,	/* I - PPD keyword */
 
 
 /*
- * End of "$Id: ppd-cache.c 12124 2014-08-28 15:37:22Z msweet $".
+ * End of "$Id: ppd-cache.c 12434 2015-01-28 16:29:06Z msweet $".
  */
