@@ -1,29 +1,25 @@
 /*
- * "$Id: testcups.c 11173 2013-07-23 12:31:34Z msweet $"
+ * "$Id: testcups.c 11558 2014-02-06 18:33:34Z msweet $"
  *
- *   CUPS API test program for CUPS.
+ * CUPS API test program for CUPS.
  *
- *   Copyright 2007-2012 by Apple Inc.
- *   Copyright 2007 by Easy Software Products.
+ * Copyright 2007-2014 by Apple Inc.
+ * Copyright 2007 by Easy Software Products.
  *
- *   These coded instructions, statements, and computer programs are the
- *   property of Apple Inc. and are protected by Federal copyright
- *   law.  Distribution and use rights are outlined in the file "LICENSE.txt"
- *   which should have been included with this file.  If this file is
- *   file is missing or damaged, see the license at "http://www.cups.org/".
+ * These coded instructions, statements, and computer programs are the
+ * property of Apple Inc. and are protected by Federal copyright
+ * law.  Distribution and use rights are outlined in the file "LICENSE.txt"
+ * which should have been included with this file.  If this file is
+ * file is missing or damaged, see the license at "http://www.cups.org/".
  *
- *   This file is subject to the Apple OS-Developed Software exception.
- *
- * Contents:
- *
- *   main()        - Main entry.
- *   dests_equal() - Determine whether two destinations are equal.
+ * This file is subject to the Apple OS-Developed Software exception.
  */
 
 /*
  * Include necessary headers...
  */
 
+#undef _CUPS_NO_DEPRECATED
 #include "string-private.h"
 #include "cups.h"
 #include "ppd.h"
@@ -170,10 +166,27 @@ main(int  argc,				/* I - Number of command-line arguments */
       else
 	puts("No password entered.");
     }
+    else if (!strcmp(argv[1], "ppd") && argc == 3)
+    {
+     /*
+      * ./testcups ppd printer
+      */
+
+      http_status_t	http_status;	/* Status */
+      char		buffer[1024];	/* PPD filename */
+      time_t		modtime = 0;	/* Last modified */
+
+      if ((http_status = cupsGetPPD3(CUPS_HTTP_DEFAULT, argv[2], &modtime,
+                                     buffer, sizeof(buffer))) != HTTP_STATUS_OK)
+        printf("Unable to get PPD: %d (%s)\n", (int)http_status,
+               cupsLastErrorString());
+      else
+        puts(buffer);
+    }
     else if (!strcmp(argv[1], "print") && argc == 5)
     {
      /*
-      * ./testcups printer file interval
+      * ./testcups print printer file interval
       */
 
       int		interval,	/* Interval between writes */
@@ -199,7 +212,7 @@ main(int  argc,				/* I - Number of command-line arguments */
       interval = atoi(argv[4]);
 
       if (cupsStartDocument(CUPS_HTTP_DEFAULT, argv[1], job_id, argv[2],
-			    CUPS_FORMAT_AUTO, 1) != HTTP_CONTINUE)
+			    CUPS_FORMAT_AUTO, 1) != HTTP_STATUS_CONTINUE)
       {
 	puts("Unable to start document!");
 	return (1);
@@ -209,20 +222,20 @@ main(int  argc,				/* I - Number of command-line arguments */
       {
 	printf("Writing %d bytes...\n", (int)bytes);
 
-	if (cupsWriteRequestData(CUPS_HTTP_DEFAULT, buffer,
-				 bytes) != HTTP_CONTINUE)
+	if (cupsWriteRequestData(CUPS_HTTP_DEFAULT, buffer, (size_t)bytes) != HTTP_STATUS_CONTINUE)
 	{
 	  puts("Unable to write bytes!");
 	  return (1);
 	}
 
         if (interval > 0)
-	  sleep(interval);
+	  sleep((unsigned)interval);
       }
 
       cupsFileClose(fp);
 
-      if (cupsFinishDocument(CUPS_HTTP_DEFAULT, argv[1]) > IPP_OK_SUBST)
+      if (cupsFinishDocument(CUPS_HTTP_DEFAULT,
+                             argv[1]) > IPP_STATUS_OK_IGNORED_OR_SUBSTITUTED)
       {
 	puts("Unable to finish document!");
 	return (1);
@@ -244,6 +257,10 @@ main(int  argc,				/* I - Number of command-line arguments */
       puts("");
       puts("    ./testcups password");
       puts("");
+      puts("Get the PPD file:");
+      puts("");
+      puts("    ./testcups ppd printer");
+      puts("");
       puts("Print a file (interval controls delay between buffers in seconds):");
       puts("");
       puts("    ./testcups print printer file interval");
@@ -509,6 +526,8 @@ enum_cb(void        *user_data,		/* I - User data (unused) */
   cups_option_t	*option;		/* Current option */
 
 
+  (void)user_data;
+
   if (flags & CUPS_DEST_FLAGS_REMOVED)
     printf("Removed '%s':\n", dest->name);
   else
@@ -566,5 +585,5 @@ show_diffs(cups_dest_t *a,		/* I - First destination */
 
 
 /*
- * End of "$Id: testcups.c 11173 2013-07-23 12:31:34Z msweet $".
+ * End of "$Id: testcups.c 11558 2014-02-06 18:33:34Z msweet $".
  */
