@@ -1,5 +1,5 @@
 /*
- * "$Id: raster.c 12679 2015-05-28 19:09:57Z msweet $"
+ * "$Id: raster.c 12748 2015-06-24 15:58:40Z msweet $"
  *
  * Raster file routines for CUPS.
  *
@@ -50,6 +50,9 @@ struct _cups_raster_s			/**** Raster stream data ****/
 			*bufptr,	/* Current (read) position in buffer */
 			*bufend;	/* End of current (read) buffer */
   size_t		bufsize;	/* Buffer size */
+#ifdef DEBUG
+  size_t		iocount;	/* Number of bytes read/written */
+#endif /* DEBUG */
 };
 
 
@@ -193,7 +196,7 @@ cupsRasterOpenIO(
         r->sync == CUPS_RASTER_REVSYNCv2)
       r->swapped = 1;
 
-    DEBUG_printf(("r->swapped=%d, r->sync=%08x\n", r->swapped, r->sync));
+    DEBUG_printf(("1cupsRasterOpenIO: r->swapped=%d, r->sync=%08x\n", r->swapped, r->sync));
   }
   else
   {
@@ -287,6 +290,8 @@ cupsRasterReadHeader2(
   * Get the raster header...
   */
 
+  DEBUG_printf(("cupsRasterReadHeader2(r=%p, h=%p)", r, h));
+
   if (!cups_raster_read_header(r))
   {
     memset(h, 0, sizeof(cups_page_header2_t));
@@ -325,9 +330,16 @@ cupsRasterReadPixels(cups_raster_t *r,	/* I - Raster stream */
   unsigned	count;			/* Repetition count */
 
 
+  DEBUG_printf(("cupsRasterReadPixels(r=%p, p=%p, len=%u)", r, p, len));
+
   if (r == NULL || r->mode != CUPS_RASTER_READ || r->remaining == 0 ||
       r->header.cupsBytesPerLine == 0)
+  {
+    DEBUG_puts("1cupsRasterReadPixels: Returning 0.");
     return (0);
+  }
+
+  DEBUG_printf(("1cupsRasterReadPixels: compressed=%d, remaining=%u", r->compressed, r->remaining));
 
   if (!r->compressed)
   {
@@ -338,7 +350,10 @@ cupsRasterReadPixels(cups_raster_t *r,	/* I - Raster stream */
     r->remaining -= len / r->header.cupsBytesPerLine;
 
     if (cups_raster_io(r, p, len) < (ssize_t)len)
+    {
+      DEBUG_puts("1cupsRasterReadPixels: Read error, returning 0.");
       return (0);
+    }
 
    /*
     * Swap bytes as needed...
@@ -354,6 +369,8 @@ cupsRasterReadPixels(cups_raster_t *r,	/* I - Raster stream */
     * Return...
     */
 
+    DEBUG_printf(("1cupsRasterReadPixels: Returning %u", len));
+
     return (len);
   }
 
@@ -382,7 +399,10 @@ cupsRasterReadPixels(cups_raster_t *r,	/* I - Raster stream */
       */
 
       if (!cups_raster_read(r, &byte, 1))
+      {
+	DEBUG_puts("1cupsRasterReadPixels: Read error, returning 0.");
 	return (0);
+      }
 
       r->count = (unsigned)byte + 1;
 
@@ -399,7 +419,10 @@ cupsRasterReadPixels(cups_raster_t *r,	/* I - Raster stream */
 	*/
 
         if (!cups_raster_read(r, &byte, 1))
+	{
+	  DEBUG_puts("1cupsRasterReadPixels: Read error, returning 0.");
 	  return (0);
+	}
 
 	if (byte & 128)
 	{
@@ -413,7 +436,10 @@ cupsRasterReadPixels(cups_raster_t *r,	/* I - Raster stream */
 	    count = (unsigned)bytes;
 
           if (!cups_raster_read(r, temp, count))
+	  {
+	    DEBUG_puts("1cupsRasterReadPixels: Read error, returning 0.");
 	    return (0);
+	  }
 
 	  temp  += count;
 	  bytes -= count;
@@ -434,7 +460,10 @@ cupsRasterReadPixels(cups_raster_t *r,	/* I - Raster stream */
 	  bytes -= count;
 
           if (!cups_raster_read(r, temp, r->bpp))
+	  {
+	    DEBUG_puts("1cupsRasterReadPixels: Read error, returning 0.");
 	    return (0);
+	  }
 
 	  temp  += r->bpp;
 	  count -= r->bpp;
@@ -506,6 +535,8 @@ cupsRasterReadPixels(cups_raster_t *r,	/* I - Raster stream */
     p         += bytes;
   }
 
+  DEBUG_printf(("1cupsRasterReadPixels: Returning %u", len));
+
   return (len);
 }
 
@@ -795,10 +826,15 @@ cupsRasterWritePixels(cups_raster_t *r,	/* I - Raster stream */
       * Write the byte-swapped buffer...
       */
 
-      return ((unsigned)cups_raster_io(r, r->buffer, len));
+      bytes = cups_raster_io(r, r->buffer, len);
     }
     else
-      return ((unsigned)cups_raster_io(r, p, len));
+      bytes = cups_raster_io(r, p, len);
+
+    if (bytes < len)
+      return (0);
+    else
+      return (len);
   }
 
  /*
@@ -822,7 +858,7 @@ cupsRasterWritePixels(cups_raster_t *r,	/* I - Raster stream */
 
       if (memcmp(p, r->pcurrent, (size_t)bytes))
       {
-        if (!cups_raster_write(r, r->pixels))
+        if (cups_raster_write(r, r->pixels) <= 0)
 	  return (0);
 
 	r->count = 0;
@@ -851,10 +887,15 @@ cupsRasterWritePixels(cups_raster_t *r,	/* I - Raster stream */
 	  r->remaining --;
 
 	  if (r->remaining == 0)
-	    return ((unsigned)cups_raster_write(r, r->pixels));
+	  {
+	    if (cups_raster_write(r, r->pixels) <= 0)
+	      return (0);
+	    else
+	      return (len);
+	  }
 	  else if (r->count == 256)
 	  {
-	    if (cups_raster_write(r, r->pixels) == 0)
+	    if (cups_raster_write(r, r->pixels) <= 0)
 	      return (0);
 
 	    r->count = 0;
@@ -891,7 +932,10 @@ cupsRasterWritePixels(cups_raster_t *r,	/* I - Raster stream */
 	r->remaining --;
 
 	if (r->remaining == 0)
-	  return ((unsigned)cups_raster_write(r, r->pixels));
+	{
+	  if (cups_raster_write(r, r->pixels) <= 0)
+	    return (0);
+	}
       }
     }
   }
@@ -911,9 +955,13 @@ cups_raster_read_header(
   size_t	len;			/* Length for read/swap */
 
 
+  DEBUG_printf(("3cups_raster_read_header(r=%p), r->mode=%d", r, r ? r->mode : 0));
+
   if (r == NULL || r->mode != CUPS_RASTER_READ)
     return (0);
 
+  DEBUG_printf(("4cups_raster_read_header: r->iocount=" CUPS_LLFMT, CUPS_LLCAST r->iocount));
+
  /*
   * Get the length of the raster header...
   */
@@ -923,6 +971,8 @@ cups_raster_read_header(
   else
     len = sizeof(cups_page_header2_t);
 
+  DEBUG_printf(("4cups_raster_read_header: len=%d", (int)len));
+
  /*
   * Read the header...
   */
@@ -930,7 +980,10 @@ cups_raster_read_header(
   memset(&(r->header), 0, sizeof(r->header));
 
   if (cups_raster_read(r, (unsigned char *)&(r->header), len) < (ssize_t)len)
+  {
+    DEBUG_printf(("4cups_raster_read_header: EOF, r->iocount=" CUPS_LLFMT, CUPS_LLCAST r->iocount));
     return (0);
+  }
 
  /*
   * Swap bytes as needed...
@@ -942,21 +995,19 @@ cups_raster_read_header(
 		temp;			/* Temporary copy */
 
 
-    DEBUG_puts("Swapping header bytes...");
+    DEBUG_puts("4cups_raster_read_header: Swapping header bytes.");
 
     for (len = 81, s = &(r->header.AdvanceDistance);
 	 len > 0;
 	 len --, s ++)
     {
-      DEBUG_printf(("%08x =>", *s));
-
       temp = *s;
       *s   = ((temp & 0xff) << 24) |
              ((temp & 0xff00) << 8) |
              ((temp & 0xff0000) >> 8) |
              ((temp & 0xff000000) >> 24);
 
-      DEBUG_printf((" %08x\n", *s));
+      DEBUG_printf(("4cups_raster_read_header: %08x => %08x", temp, *s));
     }
   }
 
@@ -966,6 +1017,8 @@ cups_raster_read_header(
 
   cups_raster_update(r);
 
+  DEBUG_printf(("4cups_raster_read_header: cupsBitsPerPixel=%u, cupsBitsPerColor=%u, cupsBytesPerLine=%u, cupsWidth=%u, cupsHeight=%u, r->bpp=%d", r->header.cupsBitsPerPixel, r->header.cupsBitsPerColor, r->header.cupsBytesPerLine, r->header.cupsWidth, r->header.cupsHeight, r->bpp));
+
   return (r->header.cupsBitsPerPixel != 0 && r->header.cupsBitsPerColor != 0 && r->header.cupsBytesPerLine != 0 && r->header.cupsHeight != 0 && (r->header.cupsBytesPerLine % r->bpp) == 0);
 }
 
@@ -983,20 +1036,31 @@ cups_raster_io(cups_raster_t *r,	/* I - Raster stream */
 		total;			/* Total bytes read/written */
 
 
-  DEBUG_printf(("4cups_raster_io(r=%p, buf=%p, bytes=" CUPS_LLFMT ")", r, buf, CUPS_LLCAST bytes));
+  DEBUG_printf(("5cups_raster_io(r=%p, buf=%p, bytes=" CUPS_LLFMT ")", r, buf, CUPS_LLCAST bytes));
 
   for (total = 0; total < (ssize_t)bytes; total += count, buf += count)
   {
     count = (*r->iocb)(r->ctx, buf, bytes - (size_t)total);
 
-    DEBUG_printf(("5cups_raster_io: count=%d, total=%d", (int)count,
-                  (int)total));
+    DEBUG_printf(("6cups_raster_io: count=%d, total=%d", (int)count, (int)total));
     if (count == 0)
+    {
+      DEBUG_puts("6cups_raster_io: Returning 0.");
       return (0);
+    }
     else if (count < 0)
+    {
+      DEBUG_puts("6cups_raster_io: Returning -1 on error.");
       return (-1);
+    }
+
+#ifdef DEBUG
+    r->iocount += (size_t)count;
+#endif /* DEBUG */
   }
 
+  DEBUG_printf(("6cups_raster_io: Returning " CUPS_LLFMT ".", CUPS_LLCAST total));
+
   return (total);
 }
 
@@ -1015,7 +1079,7 @@ cups_raster_read(cups_raster_t *r,	/* I - Raster stream */
 		total;			/* Total bytes read */
 
 
-  DEBUG_printf(("cups_raster_read(r=%p, buf=%p, bytes=" CUPS_LLFMT ")\n", r, buf, CUPS_LLCAST bytes));
+  DEBUG_printf(("5cups_raster_read(r=%p, buf=%p, bytes=" CUPS_LLFMT ")\n", r, buf, CUPS_LLCAST bytes));
 
   if (!r->compressed)
     return (cups_raster_io(r, buf, bytes));
@@ -1025,6 +1089,8 @@ cups_raster_read(cups_raster_t *r,	/* I - Raster stream */
   */
 
   count = (ssize_t)(2 * r->header.cupsBytesPerLine);
+  if (count < 65536)
+    count = 65536;
 
   if ((size_t)count > r->bufsize)
   {
@@ -1057,7 +1123,7 @@ cups_raster_read(cups_raster_t *r,	/* I - Raster stream */
   {
     count = (ssize_t)bytes - total;
 
-    DEBUG_printf(("count=" CUPS_LLFMT ", remaining=" CUPS_LLFMT ", buf=%p, bufptr=%p, bufend=%p...\n", CUPS_LLCAST count, CUPS_LLCAST remaining, buf, r->bufptr, r->bufend));
+    DEBUG_printf(("6cups_raster_read: count=" CUPS_LLFMT ", remaining=" CUPS_LLFMT ", buf=%p, bufptr=%p, bufend=%p", CUPS_LLCAST count, CUPS_LLCAST remaining, buf, r->bufptr, r->bufend));
 
     if (remaining == 0)
     {
@@ -1073,6 +1139,10 @@ cups_raster_read(cups_raster_t *r,	/* I - Raster stream */
 
 	r->bufptr = r->buffer;
 	r->bufend = r->buffer + remaining;
+
+#ifdef DEBUG
+        r->iocount += (size_t)remaining;
+#endif /* DEBUG */
       }
       else
       {
@@ -1085,6 +1155,10 @@ cups_raster_read(cups_raster_t *r,	/* I - Raster stream */
 	if (count <= 0)
 	  return (0);
 
+#ifdef DEBUG
+        r->iocount += (size_t)count;
+#endif /* DEBUG */
+
 	continue;
       }
     }
@@ -1134,6 +1208,8 @@ cups_raster_read(cups_raster_t *r,	/* I - Raster stream */
     }
   }
 
+  DEBUG_printf(("6cups_raster_read: Returning %ld", (long)total));
+
   return (total);
 }
 
@@ -1283,15 +1359,15 @@ cups_raster_write(
 			count;		/* Count */
 
 
-  DEBUG_printf(("cups_raster_write(r=%p, pixels=%p)\n", r, pixels));
+  DEBUG_printf(("3cups_raster_write(r=%p, pixels=%p)\n", r, pixels));
 
  /*
   * Allocate a write buffer as needed...
   */
 
   count = r->header.cupsBytesPerLine * 2;
-  if (count < 3)
-    count = 3;
+  if (count < 65536)
+    count = 65536;
 
   if ((size_t)count > r->bufsize)
   {
@@ -1301,7 +1377,10 @@ cups_raster_write(
       wptr = malloc(count);
 
     if (!wptr)
+    {
+      DEBUG_printf(("4cups_raster_write: Unable to allocate " CUPS_LLFMT " bytes for raster buffer: %s", CUPS_LLCAST count, strerror(errno)));
       return (-1);
+    }
 
     r->buffer  = wptr;
     r->bufsize = count;
@@ -1374,6 +1453,8 @@ cups_raster_write(
     }
   }
 
+  DEBUG_printf(("4cups_raster_write: Writing " CUPS_LLFMT " bytes.", CUPS_LLCAST (wptr - r->buffer)));
+
   return (cups_raster_io(r, r->buffer, (size_t)(wptr - r->buffer)));
 }
 
@@ -1398,7 +1479,12 @@ cups_read_fd(void          *ctx,	/* I - File descriptor as pointer */
   while ((count = read(fd, buf, bytes)) < 0)
 #endif /* WIN32 */
     if (errno != EINTR && errno != EAGAIN)
+    {
+      DEBUG_printf(("4cups_read_fd: %s", strerror(errno)));
       return (-1);
+    }
+
+  DEBUG_printf(("4cups_read_fd: Returning %d bytes.", (int)count));
 
   return (count);
 }
@@ -1450,12 +1536,15 @@ cups_write_fd(void          *ctx,	/* I - File descriptor pointer */
   while ((count = write(fd, buf, bytes)) < 0)
 #endif /* WIN32 */
     if (errno != EINTR && errno != EAGAIN)
+    {
+      DEBUG_printf(("4cups_write_fd: %s", strerror(errno)));
       return (-1);
+    }
 
   return (count);
 }
 
 
 /*
- * End of "$Id: raster.c 12679 2015-05-28 19:09:57Z msweet $".
+ * End of "$Id: raster.c 12748 2015-06-24 15:58:40Z msweet $".
  */
