@@ -1,9 +1,9 @@
 /*
- * "$Id: cancel.c 11173 2013-07-23 12:31:34Z msweet $"
+ * "$Id: cancel.c 12248 2014-11-12 16:32:57Z msweet $"
  *
  *   "cancel" command for CUPS.
  *
- *   Copyright 2007-2011 by Apple Inc.
+ *   Copyright 2007-2013 by Apple Inc.
  *   Copyright 1997-2006 by Easy Software Products.
  *
  *   These coded instructions, statements, and computer programs are the
@@ -68,6 +68,7 @@ main(int  argc,				/* I - Number of command-line arguments */
 
   for (i = 1; i < argc; i ++)
     if (argv[i][0] == '-' && argv[i][1])
+    {
       switch (argv[i][1])
       {
         case 'E' : /* Encrypt */
@@ -101,8 +102,7 @@ main(int  argc,				/* I - Number of command-line arguments */
 	    break;
 
         case 'a' : /* Cancel all jobs */
-	    purge = 1;
-	    op    = IPP_PURGE_JOBS;
+	    op = purge ? IPP_PURGE_JOBS : IPP_CANCEL_JOBS;
 	    break;
 
         case 'h' : /* Connect to host */
@@ -131,7 +131,7 @@ main(int  argc,				/* I - Number of command-line arguments */
 	    break;
 
         case 'u' : /* Username */
-	    op = IPP_PURGE_JOBS;
+	    op = IPP_CANCEL_MY_JOBS;
 
 	    if (argv[i][2] != '\0')
 	      user = argv[i] + 2;
@@ -151,12 +151,20 @@ main(int  argc,				/* I - Number of command-line arguments */
 	    }
 	    break;
 
+        case 'x' : /* Purge job(s) */
+	    purge = 1;
+
+	    if (op == IPP_CANCEL_JOBS)
+	      op = IPP_PURGE_JOBS;
+	    break;
+
 	default :
 	    _cupsLangPrintf(stderr,
 	                    _("%s: Error - unknown option \"%c\"."),
 			    argv[0], argv[i][1]);
 	    return (1);
       }
+    }
     else
     {
      /*
@@ -271,19 +279,22 @@ main(int  argc,				/* I - Number of command-line arguments */
 	ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_NAME,
                      "requesting-user-name", NULL, user);
 	ippAddBoolean(request, IPP_TAG_OPERATION, "my-jobs", 1);
+
+        if (op == IPP_CANCEL_JOBS)
+          op = IPP_CANCEL_MY_JOBS;
       }
       else
 	ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_NAME,
                      "requesting-user-name", NULL, cupsUser());
 
-      if (op == IPP_PURGE_JOBS)
+      if (purge)
 	ippAddBoolean(request, IPP_TAG_OPERATION, "purge-jobs", purge);
 
      /*
       * Do the request and get back a response...
       */
 
-      if (op == IPP_PURGE_JOBS && (!user || _cups_strcasecmp(user, cupsUser())))
+      if (op == IPP_CANCEL_JOBS && (!user || _cups_strcasecmp(user, cupsUser())))
         response = cupsDoRequest(http, request, "/admin/");
       else
         response = cupsDoRequest(http, request, "/jobs/");
@@ -304,7 +315,7 @@ main(int  argc,				/* I - Number of command-line arguments */
       ippDelete(response);
     }
 
-  if (num_dests == 0 && op == IPP_PURGE_JOBS)
+  if (num_dests == 0 && op != IPP_CANCEL_JOB)
   {
    /*
     * Open a connection to the server...
@@ -372,5 +383,5 @@ main(int  argc,				/* I - Number of command-line arguments */
 
 
 /*
- * End of "$Id: cancel.c 11173 2013-07-23 12:31:34Z msweet $".
+ * End of "$Id: cancel.c 12248 2014-11-12 16:32:57Z msweet $".
  */
